<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>DialogGraph</name>
    <message>
        <location filename="../ui/graphDialog.ui" line="17"/>
        <source>Graph</source>
        <translation>Diagramm</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="26"/>
        <source>Please wait ...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="73"/>
        <location filename="../ui/graphDialog.ui" line="76"/>
        <source>Zoom Out</source>
        <translation>Verkleinern</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="96"/>
        <location filename="../ui/graphDialog.ui" line="99"/>
        <source>Zoom In</source>
        <translation>Vergrößern</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="126"/>
        <source>Number of levels:</source>
        <translation>Anzahl der Ebenen:</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="156"/>
        <location filename="../ui/graphDialog.ui" line="159"/>
        <location filename="../ui/graphDialog.ui" line="162"/>
        <source>Save to DOT file</source>
        <translation>Als DOT-Datei speichern</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="175"/>
        <location filename="../ui/graphDialog.ui" line="178"/>
        <location filename="../ui/graphDialog.ui" line="181"/>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="194"/>
        <location filename="../ui/graphDialog.ui" line="197"/>
        <location filename="../ui/graphDialog.ui" line="200"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainWindow.ui" line="17"/>
        <source>CodeQuery</source>
        <translation>CodeQuery</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="30"/>
        <location filename="../ui/mainWindow.ui" line="33"/>
        <source>Open Database</source>
        <translation>Datenbank öffnen</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="79"/>
        <source>Auto-complete</source>
        <translation>Automatische Vervollständigung</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="93"/>
        <source>Exact match</source>
        <translation>Genaue Übereinstimmung</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="107"/>
        <location filename="../ui/mainWindow.ui" line="110"/>
        <source>File path filter</source>
        <translation>Dateipfadfilter</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="113"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="129"/>
        <location filename="../ui/mainWindow.ui" line="132"/>
        <source>File path filter, wildcard searches (* and ?) are supported</source>
        <translation>Dateipfadfilter, Platzhaltersuchen (* und ?) werden unterstützt</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="155"/>
        <location filename="../ui/mainWindow.ui" line="158"/>
        <source>Previous search term</source>
        <translation>Vorheriger Suchbegriff</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="178"/>
        <location filename="../ui/mainWindow.ui" line="181"/>
        <source>Next search term</source>
        <translation>Nächster Suchbegriff</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="207"/>
        <location filename="../ui/mainWindow.ui" line="210"/>
        <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
        <translation>Wenn "Genaue Übereinstimmung" ausgeschaltet ist, werden Platzhaltersuchen (* und ?) unterstützt</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="229"/>
        <location filename="../ui/mainWindow.ui" line="232"/>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="252"/>
        <location filename="../ui/mainWindow.ui" line="255"/>
        <source>Paste and Search</source>
        <translation>Einfügen und suchen</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="275"/>
        <location filename="../ui/mainWindow.ui" line="278"/>
        <source>List of all files</source>
        <translation>Liste aller Dateien</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="301"/>
        <location filename="../ui/mainWindow.ui" line="304"/>
        <source>Draw graph</source>
        <translation>Diagramm zeichnen</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="361"/>
        <location filename="../ui/mainWindow.ui" line="364"/>
        <source>Previous File</source>
        <translation>Vorherige Datei</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="384"/>
        <location filename="../ui/mainWindow.ui" line="387"/>
        <source>Next File</source>
        <translation>Nächste Datei</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="407"/>
        <location filename="../ui/mainWindow.ui" line="410"/>
        <source>Open in Editor</source>
        <translation>In Editor öffnen</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="430"/>
        <location filename="../ui/mainWindow.ui" line="433"/>
        <source>Go to selected line</source>
        <translation>Zur ausgewählten Zeile gehen</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="453"/>
        <location filename="../ui/mainWindow.ui" line="456"/>
        <source>Reduce font size</source>
        <translation>Schriftgrad verkleinern</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="476"/>
        <location filename="../ui/mainWindow.ui" line="479"/>
        <source>Increase font size</source>
        <translation>Schriftgrad erhöhen</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="506"/>
        <location filename="../ui/mainWindow.ui" line="509"/>
        <source>Copy, paste and search</source>
        <translation>Kopieren, einfügen und suchen</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="529"/>
        <location filename="../ui/mainWindow.ui" line="532"/>
        <source>Symbol search only for paste and search</source>
        <translation>Einfügen und Suchen auf Symbolsuche einschränken</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="535"/>
        <source>Symbol only</source>
        <translation>Nur Symbol</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="549"/>
        <location filename="../ui/mainWindow.ui" line="552"/>
        <source>Previous search result in this file</source>
        <translation>Vorheriges Suchergebnis in dieser Datei</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="572"/>
        <location filename="../ui/mainWindow.ui" line="575"/>
        <source>Next search result in this file</source>
        <translation>Nächstes Suchergebnis in dieser Datei</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="607"/>
        <source>FilePath:0</source>
        <translation>Dateipfad:0</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="636"/>
        <source>Sort by line number</source>
        <translation>Nach Zeilennummer sortieren</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="641"/>
        <source>Sort by name</source>
        <translation>Nach Namen sortieren</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="691"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="698"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="706"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="718"/>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="726"/>
        <source>Open</source>
        <translation>Offene</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="731"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="736"/>
        <source>External Editor</source>
        <translation>Externer Editor</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="741"/>
        <source>Open CQ Database</source>
        <translation>CQ-Datenbank öffnen</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="746"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="751"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="759"/>
        <source>File Viewer Settings</source>
        <translation>Dateibetrachter Einstellungen</translation>
    </message>
</context>
<context>
    <name>aboutDialog</name>
    <message>
        <location filename="../ui/aboutDialog.ui" line="23"/>
        <source>About CodeQuery</source>
        <translation>Über CodeQuery</translation>
    </message>
    <message>
        <location filename="../ui/aboutDialog.ui" line="119"/>
        <source>OK</source>
        <translation>Okay</translation>
    </message>
</context>
<context>
    <name>cqDialogGraph</name>
    <message>
        <location filename="../graphdialog.cpp" line="81"/>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location filename="../graphdialog.cpp" line="84"/>
        <source>Export Image</source>
        <translation>Bild exportieren</translation>
    </message>
    <message>
        <location filename="../graphdialog.cpp" line="95"/>
        <location filename="../graphdialog.cpp" line="114"/>
        <source>File could not be saved!</source>
        <translation>Datei konnte nicht gespeichert werden!</translation>
    </message>
    <message>
        <location filename="../graphdialog.cpp" line="103"/>
        <source>Export DOT file</source>
        <translation>DOT-Datei exportieren</translation>
    </message>
</context>
<context>
    <name>fileViewSettingsDialog</name>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="17"/>
        <source>File Viewer Settings</source>
        <translation>Dateibetrachter Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="36"/>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="49"/>
        <source>Syntax highlight theme</source>
        <translation>Syntaxhervorhebung Farbthema</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="62"/>
        <source>Tab Width (number of spaces)</source>
        <translation>Tabstoppweite (Anzahl der Leerzeichen)</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="122"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="135"/>
        <source>OK</source>
        <translation>Okay</translation>
    </message>
</context>
<context>
    <name>fileviewer</name>
    <message>
        <location filename="../fileviewer.cpp" line="248"/>
        <source>File not found</source>
        <translation>Datei nicht gefunden</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="255"/>
        <source>File could not be opened</source>
        <translation>Datei konnte nicht geöffnet werden</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="269"/>
        <source>The source file to be viewed is newer than the CodeQuery database file. You are recommended to manually regenerate the CodeQuery database file.</source>
        <translation>Die Quelldatei, die angezeigt werden soll, ist neuer als die CodeQuery-Datenbankdatei. Wir empfehlen, die CodeQuery-Datenbankdatei manuell zu regenerieren.</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="557"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="558"/>
        <source>OK</source>
        <translation>Okay</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="560"/>
        <source>External Editor Configuration</source>
        <translation>Konfiguration externer Editor</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="561"/>
        <source>Please enter the path and arguments for the external editor. Replace as follows:</source>
        <translation>Bitte geben Sie den Pfad und die Argumente für den externen Editor ein. Wie folgt ersetzen:</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="563"/>
        <source>for file path</source>
        <translation>für Dateipfad</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="565"/>
        <source>for line number</source>
        <translation>für Zeilennummer</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="567"/>
        <source>For example:</source>
        <translation>Zum Beispiel:</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="592"/>
        <source>File could not be opened!</source>
        <translation>Datei konnte nicht geöffnet werden!</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="617"/>
        <source>External editor could not be started. Please check Options!</source>
        <translation>Externer Editor konnte nicht gestartet werden. Bitte überprüfen Sie die Optionen!</translation>
    </message>
</context>
<context>
    <name>listhandler</name>
    <message>
        <location filename="../listhandler.cpp" line="125"/>
        <source>Symbol</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../listhandler.cpp" line="126"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../listhandler.cpp" line="129"/>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <location filename="../listhandler.cpp" line="129"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
</context>
<context>
    <name>mainwindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>OK</source>
        <translation>Okay</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="163"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="164"/>
        <source>Select language:</source>
        <translation>Sprache auswählen:</translation>
    </message>
</context>
<context>
    <name>searchhandler</name>
    <message>
        <location filename="../searchhandler.cpp" line="346"/>
        <source>Symbol</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="349"/>
        <source>Function or macro definition (Graph available)</source>
        <translation>Funktion oder ein Makro-Definition (Diagramm verfügbar)</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="361"/>
        <source>Class or struct (Graph available)</source>
        <translation>Klasse oder Struktur (Diagramm verfügbar)</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="355"/>
        <source>Functions calling this function</source>
        <translation>Funktionen, die diese Funktion aufrufen</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="358"/>
        <source>Functions called by this function</source>
        <translation>Von dieser Funktion aufgerufene Funktionen</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="352"/>
        <source>Calls of this function or macro</source>
        <translation>Aufrufe dieser Funktion oder dieses Makros</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="364"/>
        <source>Class which owns this member or method</source>
        <translation>Klasse, die dieses Klassenmitglied oder die Methode besitzt</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="367"/>
        <source>Members or methods of this class</source>
        <translation>Klassenmitglieder oder Methoden dieser Klasse</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="370"/>
        <source>Parent of this class</source>
        <translation>Basisklasse dieser Klasse</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="373"/>
        <source>Children of this class</source>
        <translation>Abgeleitete Klassen dieser Klasse</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="376"/>
        <source>Files including this file</source>
        <translation>Dateien, die diese Datei einbinden</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="379"/>
        <source>Full path for file</source>
        <translation>Vollständiger Pfad für Datei</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="382"/>
        <source>Functions or macros inside this file</source>
        <translation>Funktionen oder Makros in dieser Datei</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="393"/>
        <source>CodeQuery DB Files</source>
        <translation>CodeQuery DB Dateien</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="396"/>
        <source>Open CQ database file</source>
        <translation>CQ-Datenbankdatei öffnen</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="465"/>
        <source>Function Call Graph</source>
        <translation>Funktionsaufruf-Diagramm</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="469"/>
        <source>Class Inheritance Graph</source>
        <translation>Klassen-Vererbungs-Diagramm</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="485"/>
        <location filename="../searchhandler.cpp" line="488"/>
        <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
        <translation>Wenn "Genaue Übereinstimmung" ausgeschaltet ist, werden Platzhaltersuchen (* und ?) unterstützt</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="560"/>
        <source>results found</source>
        <translation>Treffer gefunden</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="579"/>
        <source>in progress</source>
        <translation>in Bearbeitung</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="580"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="677"/>
        <source>You have to first select an item from the list before pushing the Graph button.</source>
        <translation>Du musst zuerst ein Element aus der Liste auswählen, bevor die Schaltfläche "Diagramm zeichnen" verwendet werden kann.</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="806"/>
        <source>File open error</source>
        <translation>Fehler beim Öffnen der Datei</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="807"/>
        <source>Wrong file format</source>
        <translation>Falsches Dateiformat</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="808"/>
        <source>Incorrect CQ database version</source>
        <translation>Falsche CQ-Datenbankversion</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="809"/>
        <source>OK</source>
        <translation>Okay</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="811"/>
        <source>Unknown Error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
</context>
</TS>
